==> tecfy_core_package-0.1.102.tar.gz: lib/views/components/entity/map_area_property.dart <==
part of tecfy_core_client_package;

class MapAreaPropertyComponenet extends StatefulWidget {
  final String initalValue;
  final String label;
  final bool isRequired;
  final String fileId;
  final void Function(String) onChanged;
  MapAreaPropertyComponenet(
      {this.initalValue,
      this.label,
      this.isRequired,
      this.onChanged,
      this.fileId});
  @override
  _MapAreaPropertyComponenetState createState() =>
      _MapAreaPropertyComponenetState();
}

class _MapAreaPropertyComponenetState extends State<MapAreaPropertyComponenet> {
  GlobalKey _key = GlobalKey();
  // String _mapStyle;
  List<LatLng> points;
  bool marking = false;
  @override
  initState() {
    print('------------------------------ ${widget.initalValue}');
    if (widget.initalValue == null || widget.initalValue.isEmpty) {
      points = [];
    } else {
      points = json
          .decode(widget.initalValue)
          .map<LatLng>((c) => LatLng(c[0], c[1]))
          .toList();
    }
    init();
    super.initState();
  }

  init() async {
    if (points.length < 3) return;
    await Future.delayed(Duration(milliseconds: 50));
    // GoogleMap.of(_key).addPolygon('0', points,
    //     strokeColor: Colors.yellow,
    //     strokeOpacity: 1,
    //     strokeWidth: 2,
    //     fillColor: Colors.yellow,
    //     fillOpacity: 0.35);

    setState(() {});
  }

  onChanged() {
    var r = json.encode(points.map((e) => [e.latitude, e.longitude]).toList());
    widget.onChanged(r);
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
            child: GoogleMap(
              initialCameraPosition: null,
              key: _key,
              // initialZoom: 17.5,
              // initialPosition: points.length == 0
              //     ? GeoCoord(24.885449, 46.583643)
              //     : points.first,
              // mapType: MapType.hybrid,
              // mapStyle: _mapStyle,
              // interactive: true,
              onTap: (coord) {
                if (!marking) return;
                points.add(coord);
                // GoogleMap.of(_key).addMarker(Marker(coord));
                if (points.length > 2) {
                  // GoogleMap.of(_key).clearPolygons();
                  // GoogleMap.of(_key).addPolygon('0', points,
                  //     strokeColor: Colors.yellow,
                  //     strokeOpacity: 1,
                  //     strokeWidth: 2,
                  //     fillColor: Colors.yellow,
                  //     fillOpacity: 0.35);

                  onChanged();
                }
                //setState((){});
              },
              // =>
              //     _scaffoldKey.currentState.showSnackBar(SnackBar(
              //   content: Text(coord?.toString()),
              //   duration: const Duration(seconds: 2),
              // )),
            ),
            constraints: BoxConstraints(maxHeight: 500)),
        Align(
            alignment: Alignment.topRight,
            child: Padding(
                padding: EdgeInsets.all(5),
                child: Column(
                  children: [
                    CircleAvatar(
                        backgroundColor: ThemeService.mainColor,
                        child: IconButton(
                            icon: Icon(Icons.clear),
                            tooltip: 'Clear',
                            color: Colors.red,
                            onPressed: () {
                              points = [];
                              // GoogleMap.of(_key).clearPolygons();
                              // GoogleMap.of(_key).clearMarkers();
                            })),
                    SizedBox(height: 5),
                    CircleAvatar(
                        backgroundColor: ThemeService.mainColor,
                        child: IconButton(
                            icon: Icon(marking ? Icons.done : Icons.edit),
                            tooltip: marking ? 'Done' : 'Start Marke',
                            color: marking ? Colors.green : Colors.greenAccent,
                            onPressed: () {
                              setState(() {
                                marking = !marking;
                                if (marking) {
                                  // for (var p in points)
                                  // GoogleMap.of(_key).addMarker(Marker(p));
                                } else {
                                  // GoogleMap.of(_key).clearMarkers();
                                }
                              });
                            })),
                  ],
                )))
      ],
    );
  }
}

==> tecfy_core_package-1.0.5.tar.gz: lib/views/components/entity/map_area_property.dart <==
part of tecfy_core_client_package;

class MapAreaPropertyComponenet extends StatefulWidget {
  final String? initalValue;
  final String? label;
  final bool isRequired;
  final String? fileId;
  final void Function(String)? onChanged;
  MapAreaPropertyComponenet(
      {this.initalValue,
      this.label,
      this.isRequired = false,
      this.onChanged,
      this.fileId});
  @override
  _MapAreaPropertyComponenetState createState() =>
      _MapAreaPropertyComponenetState();
}

class _MapAreaPropertyComponenetState extends State<MapAreaPropertyComponenet> {
  GlobalKey _key = GlobalKey();
  // String _mapStyle;
  late List<LatLng> points;
  bool marking = false;
  @override
  initState() {
    print('------------------------------ ${widget.initalValue}');
    if (widget.initalValue == null || widget.initalValue!.isEmpty) {
      points = [];
    } else {
      points = json
          .decode(widget.initalValue!)
          .map<LatLng>((c) => LatLng(c[0], c[1]))
          .toList();
    }
    init();
    super.initState();
  }

  init() async {
    if (points.length < 3) return;
    await Future.delayed(Duration(milliseconds: 50));
    // GoogleMap.of(_key).addPolygon('0', points,
    //     strokeColor: Colors.yellow,
    //     strokeOpacity: 1,
    //     strokeWidth: 2,
    //     fillColor: Colors.yellow,
    //     fillOpacity: 0.35);

    setState(() {});
  }

  onChanged() {
    var r = json.encode(points.map((e) => [e.latitude, e.longitude]).toList());
    widget.onChanged?.call(r);
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
            child: GoogleMap(
              initialCameraPosition: CameraPosition(target: LatLng(0, 0)),
              key: _key,
              // initialZoom: 17.5,
              // initialPosition: points.length == 0
              //     ? GeoCoord(24.885449, 46.583643)
              //     : points.first,
              // mapType: MapType.hybrid,
              // mapStyle: _mapStyle,
              // interactive: true,
              onTap: (coord) {
                if (!marking) return;
                points.add(coord);
                // GoogleMap.of(_key).addMarker(Marker(coord));
                if (points.length > 2) {
                  // GoogleMap.of(_key).clearPolygons();
                  // GoogleMap.of(_key).addPolygon('0', points,
                  //     strokeColor: Colors.yellow,
                  //     strokeOpacity: 1,
                  //     strokeWidth: 2,
                  //     fillColor: Colors.yellow,
                  //     fillOpacity: 0.35);

                  onChanged();
                }
                //setState((){});
              },
              // =>
              //     _scaffoldKey.currentState.showSnackBar(SnackBar(
              //   content: Text(coord?.toString()),
              //   duration: const Duration(seconds: 2),
              // )),
            ),
            constraints: BoxConstraints(maxHeight: 500)),
        Align(
            alignment: Alignment.topRight,
            child: Padding(
                padding: EdgeInsets.all(5),
                child: Column(
                  children: [
                    CircleAvatar(
                        backgroundColor: ThemeService.mainColor,
                        child: IconButton(
                            icon: Icon(Icons.clear),
                            tooltip: 'Clear',
                            color: Colors.red,
                            onPressed: () {
                              points = [];
                              // GoogleMap.of(_key).clearPolygons();
                              // GoogleMap.of(_key).clearMarkers();
                            })),
                    SizedBox(height: 5),
                    CircleAvatar(
                        backgroundColor: ThemeService.mainColor,
                        child: IconButton(
                            icon: Icon(marking ? Icons.done : Icons.edit),
                            tooltip: marking ? 'Done' : 'Start Marke',
                            color: marking ? Colors.green : Colors.greenAccent,
                            onPressed: () {
                              setState(() {
                                marking = !marking;
                                if (marking) {
                                  // for (var p in points)
                                  // GoogleMap.of(_key).addMarker(Marker(p));
                                } else {
                                  // GoogleMap.of(_key).clearMarkers();
                                }
                              });
                            })),
                  ],
                )))
      ],
    );
  }
}
